@@ -13,9 +13,9 @@ macro_rules! declare_tags {
             $(#[$attr])*
             #[inline]
             #[allow(non_snake_case)]
-            pub fn $name<MSG>(attrs: impl IntoIterator<Item = $crate::Attribute<MSG>>, children: impl IntoIterator<Item = $crate::Node<MSG>>) -> $crate::Node<MSG>
+            pub fn $name<MSG>(attrs: impl IntoIterator<Item = $crate::vdom::Attribute<MSG>>, children: impl IntoIterator<Item = $crate::vdom::Node<MSG>>) -> $crate::vdom::Node<MSG>
                 {
-                    $crate::html::html_element(stringify!($name), attrs, children)
+                    $crate::html::html_element(None, stringify!($name), attrs, children, false)
                 }
             }
 
@@ -40,9 +40,9 @@ macro_rules! declare_sc_tags {
                 $(#[$attr])*
                 #[inline]
                 #[allow(non_snake_case)]
-                pub fn $name<MSG>(attrs: impl IntoIterator<Item = $crate::Attribute<MSG>>, children: impl IntoIterator<Item = $crate::Node<MSG>>) -> $crate::Node<MSG>
+                pub fn $name<MSG>(attrs: impl IntoIterator<Item = $crate::vdom::Attribute<MSG>>, children: impl IntoIterator<Item = $crate::vdom::Node<MSG>>) -> $crate::vdom::Node<MSG>
                     {
-                        $crate::html::html_element_self_closing(stringify!($name), attrs, children, true)
+                        $crate::html::html_element(None, stringify!($name), attrs, children, true)
                     }
                 }
 
